@@ -55,7 +55,6 @@ def cache_to_django(
                 print(
                     f'{datetime.datetime.now()} - Written {completed} {django_model.__name__} instances from cache to django')
 
-
         if cache_conf['delete']:
 
             async def check_if_need_to_delete_django_instance(redis_instances_django_ids, django_instance):
@@ -148,12 +147,17 @@ def sync_to_async_update_or_create_django_instance_from_redis_instance(
         changed_fields_to_update = {}
         for redis_field_name, redis_field_value in django_params.items():
             django_instance_fields_value = getattr(django_instance, redis_field_name)
-            if django_instance_fields_value != redis_field_value:
+            if django_instance_fields_value.__class__ == django_models.DateTimeField:
+                if django_instance_fields_value.isoformat() != redis_field_value.isoformat():
+                    changed_fields_to_update[redis_field_name] = redis_field_value
+            elif django_instance_fields_value != redis_field_value:
+                print(django_instance_fields_value, redis_field_value, type(django_instance_fields_value), type(redis_field_value))
                 changed_fields_to_update[redis_field_name] = redis_field_value
         changed_many_to_many_fields_to_update = {}
         for redis_field_name, redis_field_value in django_many_to_many_params.items():
-            django_instance_fields_value = getattr(django_instance, redis_field_name)
+            django_instance_fields_value = list(getattr(django_instance, redis_field_name).all())
             if django_instance_fields_value != redis_field_value:
+                print(django_instance_fields_value, redis_field_value, type(django_instance_fields_value), type(redis_field_value))
                 changed_many_to_many_fields_to_update[redis_field_name] = redis_field_value
         print(need_to_create, changed_fields_to_update, changed_many_to_many_fields_to_update)
     #     django_model.objects.filter(id=django_id).update(**changed_fields_to_update)
@@ -345,7 +349,7 @@ def django_to_cache(
 
             await asyncio.gather(*async_tasks)
 
-    print(f'{datetime.datetime.now()} - Deleted {django_model.__name__} instances from cache')
+        print(f'{datetime.datetime.now()} - Deleted {django_model.__name__} instances from cache')
 
     loop = asyncio.get_event_loop()
     loop.run_until_complete(
@@ -387,7 +391,7 @@ async def update_or_create_redis_instance_from_django_instance(
         redis_root.update(django_instance_model, old_redis_instance,
                           **fields_to_update
                           )
-        redis_instance = redis_root.get(django_instance_model, django_id=django_instance.id)
+        redis_instance = redis_root.get(django_instance_model, django_id=django_instance.id)[0]
         result_redis_instance_id = redis_instance['id']
 
     return result_redis_instance_id
